@@ -104,7 +104,7 @@
 #' examples in R and Stan. 2nd edition. Chapman and Hall/CRC.
 #'
 #' - Vanhove, J. (2019). Collinearity isn't a disease that needs curing.
-#' [webpage](https://janhove.github.io/analysis/2019/09/11/collinearity)
+#' [webpage](https://janhove.github.io/posts/2019-09-11-collinearity/)
 #'
 #' - Zuur AF, Ieno EN, Elphick CS. A protocol for data exploration to avoid
 #' common statistical problems: Data exploration. Methods in Ecology and
@@ -440,6 +440,14 @@ check_collinearity.zerocount <- function(x,
 
   f <- insight::find_formula(x)
 
+  # hurdle or zeroinfl model can have no zero-inflation formula, in which case
+  # we have the same formula as for conditional formula part
+  if (inherits(x, c("hurdle", "zeroinfl", "zerocount")) &&
+      component == "zero_inflated" &&
+      is.null(f[["zero_inflated"]])) {
+    f$zero_inflated <- f$conditional
+  }
+
   if (inherits(x, "mixor")) {
     terms <- labels(x$terms)
   } else {
