@@ -24,7 +24,9 @@ looic <- function(model, verbose = TRUE) {
 
   if (algorithm$algorithm != "sampling") {
     if (verbose) {
-      warning(insight::format_message("`looic()` only available for models fit using the 'sampling' algorithm."), call. = FALSE)
+      insight::format_warning(
+        "`looic()` only available for models fit using the 'sampling' algorithm."
+      )
     }
     return(NA)
   }
@@ -82,11 +84,12 @@ as.data.frame.looic <- function(x, row.names = NULL, ...) {
 print.looic <- function(x, digits = 2, ...) {
   insight::print_color("# LOOIC and ELPD with Standard Error\n\n", "blue")
 
-  out <- paste0(c(
-    sprintf("  LOOIC: %.*f [%.*f]", digits, x$LOOIC, digits, x$LOOIC_SE),
-    sprintf("   ELPD: %.*f [%.*f]", digits, x$ELPD, digits, x$ELPD_SE)
-  ),
-  collapse = "\n"
+  out <- paste0(
+    c(
+      sprintf("  LOOIC: %.*f [%.*f]", digits, x$LOOIC, digits, x$LOOIC_SE),
+      sprintf("   ELPD: %.*f [%.*f]", digits, x$ELPD, digits, x$ELPD_SE)
+    ),
+    collapse = "\n"
   )
 
   cat(out)
