@@ -76,14 +76,7 @@ model_performance.merMod <- function(model,
   }
 
   if ("AICC" %in% toupper(metrics)) {
-    out$AICc <- tryCatch(
-      {
-        performance_aicc(model, estimator = estimator)
-      },
-      error = function(e) {
-        NULL
-      }
-    )
+    out$AICc <- .safe(performance_aicc(model, estimator = estimator))
   }
 
   if ("BIC" %in% toupper(metrics)) {
